# Generated by Django 4.1.5 on 2023-01-05 17:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('scrobbles', '0003_remove_scrobble_counted_scrobble_in_progress'),
    ]

    operations = [
        migrations.AddField(
            model_name='scrobble',
            name='scrobble_log',
            field=models.TextField(blank=True, null=True),
        ),
    ]
