# Generated by Django 4.1.5 on 2023-01-12 05:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0005_album_cover_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='album',
            name='artists',
            field=models.ManyToManyField(
                blank=True, null=True, to='music.artist'
            ),
        ),
    ]
