# Generated by Django 4.1.5 on 2023-02-03 19:50

from django.db import migrations, models
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('scrobbles', '0011_chartrecord_user'),
    ]

    operations = [
        migrations.CreateModel(
            name='AudioScrobblerTSVImport',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name='ID',
                    ),
                ),
                (
                    'created',
                    django_extensions.db.fields.CreationDateTimeField(
                        auto_now_add=True, verbose_name='created'
                    ),
                ),
                (
                    'modified',
                    django_extensions.db.fields.ModificationDateTimeField(
                        auto_now=True, verbose_name='modified'
                    ),
                ),
                (
                    'tsv_file',
                    models.FileField(
                        blank=True,
                        null=True,
                        upload_to='audioscrobbler-uploads/%Y/%m-%d/',
                    ),
                ),
            ],
            options={
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
    ]
