# Generated by Django 4.1.5 on 2023-01-13 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcasts', '0004_episode_number'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='episode',
            options={},
        ),
        migrations.AlterField(
            model_name='episode',
            name='title',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
