# Generated by Django 4.1.5 on 2023-01-12 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('podcasts', '0002_episode_run_time_episode_run_time_ticks_and_more'),
        ('scrobbles', '0006_scrobble_track_alter_scrobble_video'),
    ]

    operations = [
        migrations.AddField(
            model_name='scrobble',
            name='podcast_episode',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                to='podcasts.episode',
            ),
        ),
    ]
