# Generated by Django 4.1.5 on 2023-01-13 01:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0007_alter_album_artists'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='track',
            options={},
        ),
    ]
